@@ -6,7 +6,7 @@ import requests
 def get_data(data_set):
 
    extension = '.csv'
-   dir_name =  'https://raw.githubusercontent.com/aimluae/uaedata/main/datasets/'
+   dir_name =  'https://raw.githubusercontent.com/maker57sk/aimluae/main/datasets/'
    filename = dir_name + data_set + extension
 
    if requests.get(filename).status_code == 200:
